@@ -29,7 +29,6 @@
 #include "view.h"
 #include "xparser.h"
 
-#include <kdebug.h>
 #include <QImage>
 #include <QLinearGradient>
 #include <QPainter>
@@ -45,7 +44,7 @@ Value::Value( const QString & expression )
 {
 	m_value = 0.0;
 	if ( expression.isEmpty() )
-		m_expression = "0";
+		m_expression = '0';
 	else
 		updateExpression( expression );
 }
@@ -138,11 +137,11 @@ QString PlotAppearance::penStyleToString( Qt::PenStyle style )
 			
 		case Qt::MPenStyle:
 		case Qt::CustomDashLine:
-			kWarning() << "Unsupported pen style\n";
+			qWarning() << "Unsupported pen style\n";
 			break;
 	}
 	
-	kWarning() << "Unknown style " << style ;
+	qWarning() << "Unknown style " << style ;
 	return "SolidLine";
 }
 
@@ -167,7 +166,7 @@ Qt::PenStyle PlotAppearance::stringToPenStyle( const QString & style )
 	if ( style == "DashDotDotLine" )
 		return Qt::DashDotDotLine;
 	
-	kWarning() << "Unknown style " << style ;
+	qWarning() << "Unknown style " << style ;
 	return Qt::SolidLine;
 }
 //END class PlotAppearance
@@ -249,7 +248,7 @@ DifferentialState * DifferentialStates::add()
 	if ( !m_uniqueState || m_data.isEmpty() )
 		m_data << DifferentialState( order() );
 	else
-		kDebug() << "Unable to add another state!\n";
+		qDebug() << "Unable to add another state!\n";
 	
 	return & m_data[ size() - 1 ];
 }
@@ -376,7 +375,9 @@ bool Equation::looksLikeFunction( ) const
 void Equation::updateVariables()
 {
     if ( type() == Constant )
+    {
         return;
+    }
     
 	m_variables.clear();
 	
@@ -385,12 +386,12 @@ void Equation::updateVariables()
 		int p1 = m_fstr.indexOf( '(' );
 		int p2 = m_fstr.indexOf( ')' );
 	
-		QStringList splitted;
+		QStringList listSplit;
 		if ( (p1 != -1) && (p2 != -1) )
-			splitted = m_fstr.mid( p1+1, p2-p1-1 ).split( ',', QString::SkipEmptyParts );
+			listSplit = m_fstr.mid( p1+1, p2-p1-1 ).split( ',', QString::SkipEmptyParts );
 		
 		// Variables shouldn't contain spaces!
-		foreach ( QString s, splitted ) { //krazy:exclude=foreach
+		foreach ( QString s, listSplit ) { //krazy:exclude=foreach
 			s = s.remove(' ');
 			if ( !s.isEmpty() )
 				m_variables << s;
@@ -484,7 +485,7 @@ bool Equation::setFstr( const QString & fstr, int * error, int * errorPosition,
 	} \
 	else \
 	{ \
-		kDebug() << "fstr "<<fstr<<" invalid, but forcing anyway: " << Parser::errorString( Parser::Error(*error) ) << " at position " << *errorPosition; \
+		qDebug() << "fstr "<<fstr<<" invalid, but forcing anyway: " << Parser::errorString( Parser::Error(*error) ) << " at position " << *errorPosition; \
 		mem.clear(); \
 	}
 	
@@ -692,7 +693,7 @@ PlotAppearance & Function::plotAppearance( PMode plot )
 			return integral;
 	}
 	
-	kError() << "Unknown plot " << plot << endl;
+	qCritical() << "Unknown plot " << plot << endl;
 	return f0;
 }
 PlotAppearance Function::plotAppearance( PMode plot ) const
@@ -711,7 +712,7 @@ PlotAppearance Function::plotAppearance( PMode plot ) const
 			return integral;
 	}
 	
-	kError() << "Unknown plot " << plot << endl;
+	qCritical() << "Unknown plot " << plot << endl;
 	return f0;
 }
 
@@ -742,7 +743,7 @@ QString Function::typeToString( Type type )
 			return "differential";
 	}
 	
-	kWarning() << "Unknown type " << type ;
+	qWarning() << "Unknown type " << type ;
 	return "unknown";
 }
 
@@ -764,7 +765,7 @@ Function::Type Function::stringToType( const QString & type )
 	if ( type == "differential" )
 		return Differential;
 	
-	kWarning() << "Unknown type " << type ;
+	qWarning() << "Unknown type " << type ;
 	return Cartesian;
 }
 
@@ -1066,11 +1067,12 @@ double Plot::parameterValue() const
 		{
 			if ( (parameter.listPos() >= 0) && (parameter.listPos() < m_function->m_parameters.list.size()) )
 				return m_function->m_parameters.list[ parameter.listPos() ].value();
+			return 0;
 		}
 		
 		case Parameter::Animated:
 		{
-			kWarning() << "Shouldn't use this function for animated parameter!\n";
+			qWarning() << "Shouldn't use this function for animated parameter!\n";
 			return 0;
 		}
 	}
@@ -1096,7 +1098,7 @@ void Plot::differentiate()
 			break;
 
 		case Function::Derivative2:
-			kWarning() << "Can't handle this yet!\n";
+			qWarning() << "Can't handle this yet!\n";
 			break;
 	}
 }
@@ -1107,7 +1109,7 @@ void Plot::integrate()
 	switch ( plotMode )
 	{
 		case Function::Integral:
-			kWarning() << "Can't handle this yet!\n";
+			qWarning() << "Can't handle this yet!\n";
 			break;
 
 		case Function::Derivative0:
@@ -1163,7 +1165,7 @@ int Plot::derivativeNumber( ) const
 			return 2;
 	}
 	
-	kWarning() << "Unknown derivative number.\n";
+	qWarning() << "Unknown derivative number.\n";
 	return 0;
 }
 
