@@ -28,15 +28,14 @@
 #include "view.h"
 #include "xparser.h"
 
-#include <kdebug.h>
-#include <kinputdialog.h>
-#include <kmessagebox.h>
-#include <kstandarddirs.h>
-
-#include <qdom.h>
+#include <QDebug>
+#include <QDialogButtonBox>
+#include <QStandardPaths>
 #include <QTimer>
 
 #include <assert.h>
+#include <KConfigGroup>
+#include <KMessageBox>
 
 
 #include "ui_constantseditor.h"
@@ -52,38 +51,39 @@ class ConstantsEditorWidget : public QWidget, public Ui::ConstantsEditor
 
 //BEGIN class KConstantEditor
 KConstantEditor::KConstantEditor( QWidget * parent )
-	: KDialog( parent )
+	: QDialog( parent )
 {
 	m_widget = new ConstantsEditorWidget( this );
-	m_widget->layout()->setMargin( 0 );
-	setMainWidget( m_widget );
-	setButtons( Close );
-	
+
+	QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+	connect(buttonBox, &QDialogButtonBox::rejected, this, &KConstantEditor::reject);
+	m_widget->gridLayout->addWidget(buttonBox, 4, 1, 1, 1);
+
 	m_widget->cmdNew->setIcon( QIcon::fromTheme("document-new") );
 	m_widget->cmdDelete->setIcon( QIcon::fromTheme("edit-delete") );
 	
-	setCaption( i18n("Constants Editor") );
+	setWindowTitle( i18n("Constants Editor") );
     
-    connect( this, SIGNAL(finished()), this, SLOT(dialogFinished()) );
+	connect( this, &KConstantEditor::finished, this, &KConstantEditor::dialogFinished );
 	
 	m_constantValidator = new ConstantValidator( this );
 	m_widget->nameEdit->setValidator( m_constantValidator );
 	
 	updateConstantsList();
 	
-	connect( m_widget->nameEdit, SIGNAL( textEdited( const QString & ) ), this, SLOT( constantNameEdited( const QString & ) ) );
-	connect( m_widget->valueEdit, SIGNAL( textEdited( const QString & ) ), this, SLOT( saveCurrentConstant() ) );
+	connect( m_widget->nameEdit, &KLineEdit::textEdited, this, &KConstantEditor::constantNameEdited );
+	connect( m_widget->valueEdit, &EquationEdit::textEdited, this, &KConstantEditor::saveCurrentConstant );
 	
-	connect( m_widget->nameEdit, SIGNAL( textChanged( const QString & ) ), this, SLOT( checkValueValid() ) );
-	connect( m_widget->valueEdit, SIGNAL( textChanged( const QString & ) ), this, SLOT( checkValueValid() ) );
+	connect( m_widget->nameEdit, &KLineEdit::textChanged, this, &KConstantEditor::checkValueValid );
+	connect( m_widget->valueEdit, &EquationEdit::textChanged, this, &KConstantEditor::checkValueValid );
 	
-	connect( m_widget->cmdNew, SIGNAL( clicked() ), this, SLOT( cmdNew_clicked() ) );
-	connect( m_widget->cmdDelete, SIGNAL( clicked() ), this, SLOT( cmdDelete_clicked() ) );
+	connect( m_widget->cmdNew, &QPushButton::clicked, this, &KConstantEditor::cmdNew_clicked );
+	connect( m_widget->cmdDelete, &QPushButton::clicked, this, &KConstantEditor::cmdDelete_clicked );
 	
-	connect( m_widget->constantList, SIGNAL(currentItemChanged( QTreeWidgetItem *, QTreeWidgetItem * )), this, SLOT(selectedConstantChanged( QTreeWidgetItem * )) );
-	connect( m_widget->constantList, SIGNAL(itemClicked( QTreeWidgetItem *, int )), this, SLOT(itemClicked()) );
+	connect( m_widget->constantList, &QTreeWidget::currentItemChanged, this, &KConstantEditor::selectedConstantChanged );
+	connect( m_widget->constantList, &QTreeWidget::itemClicked, this, &KConstantEditor::itemClicked );
 	
-	connect( XParser::self()->constants(), SIGNAL(constantsChanged()), this, SLOT(updateConstantsList()) );
+	connect( XParser::self()->constants(), &Constants::constantsChanged, this, &KConstantEditor::updateConstantsList );
 	
 	checkValueValid();
 }
@@ -241,7 +241,7 @@ bool KConstantEditor::checkValueValid()
 
 void KConstantEditor::itemClicked()
 {
-	QTimer::singleShot( 0, this, SLOT( saveCurrentConstant() ) );
+	QTimer::singleShot( 0, this, SLOT(saveCurrentConstant()) );
 }
 //END class KConstantEditor
 
