@@ -26,38 +26,34 @@
 #include "maindlg.h"
 
 // Qt includes
+#include <QDebug>
+#include <QFileDialog>
+#include <QIcon>
+#include <QImageWriter>
 #include <QMainWindow>
-#include <QPixmap>
-#include <QSvgGenerator>
-#include <QTimer>
 #include <QMenu>
-#include <QtPrintSupport/QPrinter>
-#include <QtPrintSupport/QPrintDialog>
+#include <QMimeDatabase>
+#include <QMimeType>
+#include <QPixmap>
+#include <QPrintDialog>
+#include <QPrinter>
+#include <QStandardPaths>
+#include <QSvgGenerator>
+#include <QTemporaryFile>
+#include <QTimer>
 
 // KDE includes
-#include <k4aboutdata.h>
-#include <kconfigdialog.h>
-#include <kconfigdialogmanager.h>
-#include <kdebug.h>
-#include <kedittoolbar.h>
-#include <kfiledialog.h>
-#include <kimageio.h>
-#include <kio/netaccess.h>
-#include <kcomponentdata.h>
-#include <klineedit.h>
-#include <kmessagebox.h>
-#include <kmimetype.h>
-#include <kstandarddirs.h>
-#include <kstandardaction.h>
-#include <ktemporaryfile.h>
-#include <ktoolbar.h>
-#include <ktoolinvocation.h>
-#include <krecentfilesaction.h>
-#include <kactioncollection.h>
-#include <khelpclient.h>
-#include <QIcon>
-#include <kiconloader.h>
-#include <kapplication.h>
+#include <KActionCollection>
+#include <KConfigDialog>
+#include <KConfigDialogManager>
+#include <KHelpClient>
+#include <KIO/StatJob>
+#include <KIO/StoredTransferJob>
+#include <KLineEdit>
+#include <KMessageBox>
+#include <KStandardAction>
+#include <KToolBar>
+#include <KToolInvocation>
 
 // local includes
 #include "calculator.h"
@@ -140,7 +136,7 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 	assert( !m_self ); // this class should only be constructed once
 	m_self = this;
 
-	kDebug() << "parentWidget->objectName():" << parentWidget->objectName();
+	qDebug() << "parentWidget->objectName():" << parentWidget->objectName();
 	if ( QString(parentWidget->objectName()).startsWith("KmPlot") )
 	{
 		setXMLFile("kmplot_part.rc");
@@ -158,7 +154,7 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 	m_popupmenu = new QMenu( parentWidget );
 	m_newPlotMenu = new QMenu( parentWidget );
 	(void) new View( m_readonly, m_popupmenu, parentWidget );
-	connect( View::self(), SIGNAL( setStatusBarText(const QString &)), this, SLOT( setReadOnlyStatusBarText(const QString &) ) );
+	connect( View::self(), &View::setStatusBarText, this, &MainDlg::setReadOnlyStatusBarText );
 
 	m_functionEditor = 0;
 	if ( !m_readonly )
@@ -182,14 +178,14 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 	m_currentState = kmplotio->currentState();
 	m_saveCurrentStateTimer = new QTimer( this );
 	m_saveCurrentStateTimer->setSingleShot( true );
-	connect( m_saveCurrentStateTimer, SIGNAL(timeout()), this, SLOT(saveCurrentState()) );
+	connect( m_saveCurrentStateTimer, &QTimer::timeout, this, &MainDlg::saveCurrentState );
 	//END undo/redo stuff
 
 
 
 	// Allow config manager to read from equation edits
-	KConfigDialogManager::changedMap()->insert( "EquationEdit", SIGNAL(textEdited(const QString &)) );
-	// Let's create a Configure Diloag
+	KConfigDialogManager::changedMap()->insert( "EquationEdit", SIGNAL(textEdited(QString)) );
+	// Let's create a Configure Dialog
 	m_settingsDialog = new KConfigDialog( parentWidget, "settings", Settings::self() );
 //FIXME port to KF5
 //	m_settingsDialog->setHelp("general-config");
@@ -200,7 +196,7 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 	m_fontsSettings = new SettingsPageFonts( View::self() );
 	m_diagramSettings = new SettingsPageDiagram( View::self() );
 
-	// Make sure the dialog is at a good default size (hmm kdialog should do this automatically?)
+	// Make sure the dialog is at a good default size (hmm QDialog should do this automatically?)
 	QSize minSize = m_generalSettings->layout()->minimumSize()
 			.expandedTo( m_colorSettings->layout()->minimumSize() )
 			.expandedTo( m_fontsSettings->layout()->minimumSize() )
@@ -213,7 +209,7 @@ MainDlg::MainDlg(QWidget *parentWidget, QObject *parent, const QVariantList& ) :
 	m_settingsDialog->addPage( m_fontsSettings, i18n("Fonts"), "preferences-desktop-font", i18n("Fonts") );
 	// User edited the configuration - update your local copies of the
 	// configuration data
-	connect( m_settingsDialog, SIGNAL( settingsChanged( const QString &) ), View::self(), SLOT(drawPlot() ) );
+	connect( m_settingsDialog, &KConfigDialog::settingsChanged, View::self(), QOverload<>::of(&View::drawPlot) );
 
 
     new MainDlgAdaptor(this);
@@ -231,13 +227,13 @@ MainDlg::~MainDlg()
 void MainDlg::setupActions()
 {
 	// standard actions
-        m_recentFiles = KStandardAction::openRecent( this, SLOT( slotOpenRecent( const QUrl& ) ), this );
+        m_recentFiles = KStandardAction::openRecent( this, SLOT(slotOpenRecent(QUrl)), this );
         actionCollection()->addAction( "file_open_recent", m_recentFiles );
-	actionCollection()->addAction( KStandardAction::Print, "file_print", this, SLOT( slotPrint() ) );
-	KStandardAction::save( this, SLOT( slotSave() ), actionCollection() );
-	KStandardAction::saveAs( this, SLOT( slotSaveas() ), actionCollection() );
+	actionCollection()->addAction( KStandardAction::Print, "file_print", this, SLOT(slotPrint()) );
+	KStandardAction::save( this, SLOT(slotSave()), actionCollection() );
+	KStandardAction::saveAs( this, SLOT(slotSaveas()), actionCollection() );
 
-	QAction *prefs  = KStandardAction::preferences( this, SLOT( slotSettings() ), actionCollection());
+	QAction *prefs  = KStandardAction::preferences( this, SLOT(slotSettings()), actionCollection());
 	prefs->setText( i18n( "Configure KmPlot..." ) );
 
 	// KmPlot specific actions
@@ -246,7 +242,7 @@ void MainDlg::setupActions()
 	QAction * exportAction = actionCollection()->addAction( "export" );
         exportAction->setText( i18n( "E&xport..." ) );
         exportAction->setIcon( QIcon::fromTheme( "document-export" ) );
-	connect( exportAction, SIGNAL(triggered(bool)), this, SLOT( slotExport() ) );
+	connect( exportAction, &QAction::triggered, this, &MainDlg::slotExport );
 	//END file menu
 
 
@@ -260,12 +256,12 @@ void MainDlg::setupActions()
 	QAction * editAxes = actionCollection()->addAction( "editaxes" );
         editAxes->setText( i18n( "&Coordinate System..." ) );
 	editAxes->setIcon( QIcon::fromTheme("coords.png") );
-	connect( editAxes, SIGNAL(triggered(bool)), this, SLOT( editAxes() ) );
+	connect( editAxes, &QAction::triggered, this, &MainDlg::editAxes );
 
 	QAction * editConstants = actionCollection()->addAction( "editconstants" );
         editConstants->setText( i18n( "&Constants..." ) );
 	editConstants->setIcon( QIcon::fromTheme("editconstants.png") );
-	connect( editConstants, SIGNAL(triggered(bool)), this, SLOT( editConstants() ) );
+	connect( editConstants, &QAction::triggered, this, &MainDlg::editConstants );
 	//END edit menu
 
 
@@ -276,22 +272,26 @@ void MainDlg::setupActions()
         zoomIn->setText( i18n("Zoom &In") );
 	actionCollection()->setDefaultShortcut( zoomIn, QKeySequence(Qt::ControlModifier | Qt::Key_1) );
 	zoomIn->setIcon( QIcon::fromTheme("zoom-in") );
-	connect( zoomIn, SIGNAL(triggered(bool)), View::self(), SLOT(zoomIn()) );
+	connect( zoomIn, &QAction::triggered, View::self(), QOverload<>::of(&View::zoomIn) );
 
 	QAction * zoomOut = actionCollection()->addAction( "zoom_out" );
         zoomOut->setText(i18n("Zoom &Out"));
 	actionCollection()->setDefaultShortcut( zoomOut, QKeySequence(Qt::ControlModifier | Qt::Key_2) );
 	zoomOut->setIcon( QIcon::fromTheme("zoom-out") );
-	connect( zoomOut, SIGNAL(triggered(bool)), View::self(), SLOT( zoomOut() ) );
+	connect( zoomOut, &QAction::triggered, View::self(), QOverload<>::of(&View::zoomOut) );
 
 	QAction * zoomTrig = actionCollection()->addAction( "zoom_trig" );
         zoomTrig->setText( i18n("&Fit Widget to Trigonometric Functions") );
-	connect( zoomTrig, SIGNAL(triggered(bool)), View::self(), SLOT( zoomToTrigonometric() ) );
+	connect( zoomTrig, &QAction::triggered, View::self(), &View::zoomToTrigonometric );
 
 	QAction * resetView = actionCollection()->addAction( "reset_view" );
 	resetView->setText( i18n( "Reset View" ) );
 	resetView->setIcon( QIcon::fromTheme("resetview") );
-	connect( resetView, SIGNAL(triggered(bool)), this, SLOT( slotResetView() ) );
+	connect( resetView, &QAction::triggered, this, &MainDlg::slotResetView );
+
+	View::self()->m_menuSliderAction = actionCollection()->add<KToggleAction>( "options_configure_show_sliders" );
+	View::self()->m_menuSliderAction->setText( i18n( "Show Sliders" ) );
+	connect( View::self()->m_menuSliderAction, &QAction::toggled, this, &MainDlg::toggleShowSliders );
 	//END view menu
 
 
@@ -299,21 +299,21 @@ void MainDlg::setupActions()
 	QAction *mnuCalculator = actionCollection()->addAction( "calculator" );
 	mnuCalculator->setText( i18n( "Calculator") );
 	mnuCalculator->setIcon( QIcon::fromTheme("system-run") );
-	connect( mnuCalculator, SIGNAL(triggered(bool)), this, SLOT( calculator() ) );
+	connect( mnuCalculator, &QAction::triggered, this, &MainDlg::calculator );
 
 	QAction *mnuArea = actionCollection()->addAction( "grapharea" );
         mnuArea->setText( i18n( "Plot &Area..." ) );
-	connect( mnuArea, SIGNAL(triggered(bool)),this, SLOT( graphArea() )  );
+	connect( mnuArea, &QAction::triggered, this, &MainDlg::graphArea );
 
 	QAction *mnuMaxValue = actionCollection()->addAction( "maximumvalue" );
         mnuMaxValue->setText( i18n( "Find Ma&ximum..." ) );
 	mnuMaxValue->setIcon( QIcon::fromTheme("maximum") );
-	connect( mnuMaxValue, SIGNAL(triggered(bool)), this, SLOT( findMaximumValue() ) );
+	connect( mnuMaxValue, &QAction::triggered, this, &MainDlg::findMaximumValue );
 
 	QAction *mnuMinValue = actionCollection()->addAction( "minimumvalue" );
         mnuMinValue->setText( i18n( "Find Mi&nimum..." ) );
 	mnuMinValue->setIcon( QIcon::fromTheme("minimum") );
-	connect( mnuMinValue, SIGNAL(triggered(bool)), this, SLOT( findMinimumValue() ) );
+	connect( mnuMinValue, &QAction::triggered, this, &MainDlg::findMinimumValue );
 	//END tools menu
 
 
@@ -321,7 +321,7 @@ void MainDlg::setupActions()
 	QAction * namesAction = actionCollection()->addAction( "names" );
         namesAction->setText( i18n( "Predefined &Math Functions" ) );
 	namesAction->setIcon( QIcon::fromTheme("functionhelp") );
-	connect( namesAction, SIGNAL(triggered(bool)), this, SLOT( slotNames() ) );
+	connect( namesAction, &QAction::triggered, this, &MainDlg::slotNames );
 	//END help menu
 
 
@@ -329,64 +329,59 @@ void MainDlg::setupActions()
 	QAction * newFunction = actionCollection()->addAction( "newcartesian" );
         newFunction->setText( i18n( "Cartesian Plot" ) );
 	newFunction->setIcon( QIcon::fromTheme("newfunction") );
-	connect( newFunction, SIGNAL(triggered(bool)), m_functionEditor, SLOT( createCartesian() ) );
+	connect( newFunction, &QAction::triggered, m_functionEditor, &FunctionEditor::createCartesian );
 	m_newPlotMenu->addAction( newFunction );
 
 	QAction * newParametric = actionCollection()->addAction( "newparametric" );
         newParametric->setText( i18n( "Parametric Plot" ) );
 	newParametric->setIcon( QIcon::fromTheme("newparametric") );
-	connect( newParametric, SIGNAL(triggered(bool)), m_functionEditor, SLOT( createParametric() ) );
+	connect( newParametric, &QAction::triggered, m_functionEditor, &FunctionEditor::createParametric );
 	m_newPlotMenu->addAction( newParametric );
 
 	QAction * newPolar = actionCollection()->addAction( "newpolar" );
         newPolar->setText( i18n( "Polar Plot" ) );
 	newPolar->setIcon( QIcon::fromTheme("newpolar") );
-	connect( newPolar, SIGNAL(triggered(bool)), m_functionEditor, SLOT( createPolar() ) );
+	connect( newPolar, &QAction::triggered, m_functionEditor, &FunctionEditor::createPolar );
 	m_newPlotMenu->addAction( newPolar );
 
 	QAction * newImplicit = actionCollection()->addAction( "newimplicit" );
         newImplicit->setText( i18n( "Implicit Plot" ) );
 	newImplicit->setIcon( QIcon::fromTheme("newimplicit") );
-	connect( newImplicit, SIGNAL(triggered(bool)), m_functionEditor, SLOT( createImplicit() ) );
+	connect( newImplicit, &QAction::triggered, m_functionEditor, &FunctionEditor::createImplicit );
 	m_newPlotMenu->addAction( newImplicit );
 
 	QAction * newDifferential = actionCollection()->addAction( "newdifferential" );
         newDifferential->setText( i18n( "Differential Plot" ) );
 	newDifferential->setIcon( QIcon::fromTheme("newdifferential") );
-	connect( newDifferential, SIGNAL(triggered(bool)), m_functionEditor, SLOT( createDifferential() ) );
+	connect( newDifferential, &QAction::triggered, m_functionEditor, &FunctionEditor::createDifferential );
 	m_newPlotMenu->addAction( newDifferential );
 	//END new plots menu
 
 
-	View::self()->m_menuSliderAction = actionCollection()->add<KToggleAction>( "options_configure_show_sliders" );
-        View::self()->m_menuSliderAction->setText( i18n( "Show Sliders" ) );
-	connect( View::self()->m_menuSliderAction, SIGNAL(triggered(bool)), this, SLOT( toggleShowSliders() ) );
-
-
 	//BEGIN function popup menu
 	QAction *mnuEdit = actionCollection()->addAction( "mnuedit"  );
         mnuEdit->setText(i18n("&Edit"));
 	m_firstFunctionAction = mnuEdit;
 	mnuEdit->setIcon( QIcon::fromTheme("editplots") );
-	connect(mnuEdit , SIGNAL(triggered(bool)), View::self(), SLOT( editCurrentPlot() ) );
+	connect(mnuEdit, &QAction::triggered, View::self(), &View::editCurrentPlot );
 	m_popupmenu->addAction( mnuEdit );
 
 	QAction *mnuHide = actionCollection()->addAction( "mnuhide" );
         mnuHide->setText( i18n("&Hide") );
-	connect( mnuHide, SIGNAL(triggered(bool)), View::self(), SLOT( hideCurrentFunction() ) );
+	connect( mnuHide, &QAction::triggered, View::self(), &View::hideCurrentFunction );
 	m_popupmenu->addAction( mnuHide );
 
 	QAction *mnuRemove = actionCollection()->addAction( "mnuremove"  );
         mnuRemove->setText(i18n("&Remove"));
 	mnuRemove->setIcon( QIcon::fromTheme("edit-delete") );
-	connect( mnuRemove, SIGNAL(triggered(bool)), View::self(), SLOT( removeCurrentPlot() ) );
+	connect( mnuRemove, &QAction::triggered, View::self(), &View::removeCurrentPlot );
 	m_popupmenu->addAction( mnuRemove );
 
 	m_popupmenu->addSeparator();
 
 	QAction * animateFunction = actionCollection()->addAction( "animateFunction" );
         animateFunction->setText(i18n("Animate Plot..."));
-	connect( animateFunction, SIGNAL(triggered(bool)), View::self(), SLOT( animateFunction() ) );
+	connect( animateFunction, &QAction::triggered, View::self(), &View::animateFunction );
 	m_popupmenu->addAction( animateFunction );
 	m_popupmenu->addSeparator();
 
@@ -400,7 +395,7 @@ void MainDlg::setupActions()
 
 void MainDlg::undo()
 {
-	kDebug() ;
+	qDebug() ;
 
 	if ( m_undoStack.isEmpty() )
 		return;
@@ -418,7 +413,7 @@ void MainDlg::undo()
 
 void MainDlg::redo()
 {
-	kDebug() ;
+	qDebug() ;
 
 	if ( m_redoStack.isEmpty() )
 		return;
@@ -503,7 +498,7 @@ void MainDlg::slotSave()
 				return;
 		}
 		kmplotio->save( this->url() );
-		kDebug() << "saved";
+		qDebug() << "saved";
 		m_modified = false;
 	}
 
@@ -513,24 +508,13 @@ void MainDlg::slotSaveas()
 {
 	if (m_readonly)
 		return;
-	const QUrl url = KFileDialog::getSaveUrl(QUrl::fromLocalFile(QDir::currentPath()),
-			    i18n( "*.fkt|KmPlot Files (*.fkt)\n*|All Files" ),
-			    m_parent, i18n( "Save As" ) );
+	const QUrl url = QFileDialog::getSaveFileUrl(m_parent, i18n( "Save As" ), QUrl::fromLocalFile(QDir::currentPath()),
+			    i18n( "KmPlot Files (*.fkt);;All Files (*)" )
+			      );
 
 	if ( url.isEmpty() )
 		return;
 
-	bool exists = KIO::NetAccess::exists( url, KIO::NetAccess::DestinationSide, m_parent );
-	if ( exists )
-	{
-		// check if file exists and overwriting is ok.
-
-		int answer = KMessageBox::warningContinueCancel( m_parent, i18n( "A file named \"%1\" already exists. Are you sure you want to continue and overwrite this file?", url.url()), i18n( "Overwrite File?" ), KGuiItem( i18n( "&Overwrite" ) ) );
-
-		if ( answer != KMessageBox::Continue )
-			return;
-	}
-
 	if ( !kmplotio->save( url ) )
 		KMessageBox::error(m_parent, i18n("The file could not be saved") );
 	else
@@ -544,44 +528,48 @@ void MainDlg::slotSaveas()
 
 void MainDlg::slotExport()
 {
-	QString filter = KImageIO::pattern( KImageIO::Writing );
-	filter += i18n("\n*.svg|Scalable Vector Graphics");
+	QString filters;
+	QMimeDatabase mimeDatabase;
+	foreach (const QByteArray &mimeType, QImageWriter::supportedMimeTypes()) {
+		const QString filter = mimeDatabase.mimeTypeForName(QLatin1String(mimeType)).filterString();
+		if (!filter.isEmpty()) {
+			if (mimeType == QByteArrayLiteral("image/png")) {
+				if (!filters.isEmpty()) {
+					filters.prepend(QStringLiteral(";;"));
+				}
+				filters.prepend(filter);
+			} else {
+				if (!filters.isEmpty()) {
+					filters.append(QStringLiteral(";;"));
+                                }
+				filters.append(filter);
+			}
+		}
+	}
+	if (!filters.isEmpty()) {
+		filters.append(QStringLiteral(";;"));
+	}
+	filters.append(i18n("Scalable Vector Graphics (*.svg)"));
 
-	QUrl url = KFileDialog::getSaveUrl(QUrl::fromLocalFile(QDir::currentPath()), filter, m_parent, i18n( "Export as Image" ) );
+	QUrl url = QFileDialog::getSaveFileUrl(m_parent, i18nc("@title:window", "Export as Image"), QUrl::fromLocalFile(QDir::currentPath()), filters);
 
 	if ( !url.isValid() )
 		return;
-	bool exists = KIO::NetAccess::exists( url, KIO::NetAccess::DestinationSide, m_parent );
-	if ( exists )
-	{
-		// check if file exists and overwriting is ok.
 
-		int answer = KMessageBox::warningContinueCancel( m_parent, i18n( "A file named \"%1\" already exists. Are you sure you want to continue and overwrite this file?", url.url()), i18n( "Overwrite File?" ), KGuiItem( i18n( "&Overwrite" ) ) );
+	QMimeType mimeType = mimeDatabase.mimeTypeForUrl( url );
+	qDebug() << "mimetype: " << mimeType.name();
 
-		if ( answer != KMessageBox::Continue )
-			return;
-	}
-
-	KMimeType::Ptr mimeType = KMimeType::findByUrl( url );
-	kDebug() << "mimetype: " << mimeType->name();
-
-	bool isSvg = mimeType->name() == "image/svg+xml";
-
-	if ( !KImageIO::isSupported( mimeType->name(), KImageIO::Writing ) && !isSvg )
-	{
-		KMessageBox::sorry( m_parent, i18n( "Sorry, this file format is not supported." ) );
-		return;
-	};
+	bool isSvg = mimeType.name() == "image/svg+xml";
 
 	bool saveOk = true;
 
 	if ( isSvg )
 	{
 		QSvgGenerator img;
-		img.setSize( View::self()->size() );
+		img.setViewBox( QRect( QPoint(0, 0), View::self()->size() ) );
 
 		QFile file;
-		KTemporaryFile tmp;
+		QTemporaryFile tmp;
 
 		if ( url.isLocalFile() )
 		{
@@ -590,21 +578,28 @@ void MainDlg::slotExport()
 		}
 		else
 		{
-			tmp.setSuffix( ".svg" );
+ 			tmp.setFileTemplate(QDir::tempPath() + QLatin1String("/kmplot_XXXXXX") + QLatin1String(".svg")); 
 			img.setOutputDevice( &tmp );
 		}
 
 		View::self()->draw( &img, View::SVG );
 
 		if ( !url.isLocalFile() )
-			saveOk &= KIO::NetAccess::upload(tmp.fileName(), url, 0);
+		{
+		    Q_CONSTEXPR int permission = -1;
+		    QFile file(tmp.fileName());
+		    file.open(QIODevice::ReadOnly);
+		    KIO::StoredTransferJob *putjob = KIO::storedPut(file.readAll(), url, permission, KIO::JobFlag::Overwrite);
+		    saveOk &= putjob->exec();
+		    file.close();
+		}
 	}
 	else
 	{
 		QPixmap img( View::self()->size() );
 		View::self()->draw( & img, View::Pixmap );
 
-		QStringList types = KImageIO::typeForMime( mimeType->name() );
+		QStringList types = mimeType.suffixes();
 		if ( types.isEmpty() )
 			return; // TODO error dialog?
 
@@ -612,10 +607,15 @@ void MainDlg::slotExport()
 			saveOk = img.save( url.toLocalFile(), types.at(0).toLatin1() );
 		else
 		{
-			KTemporaryFile tmp;
+			QTemporaryFile tmp;
 			tmp.open();
 			img.save( tmp.fileName(), types.at(0).toLatin1() );
-			saveOk = KIO::NetAccess::upload(tmp.fileName(), url, 0);
+			Q_CONSTEXPR int permission = -1;
+			QFile file(tmp.fileName());
+			file.open(QIODevice::ReadOnly);
+			KIO::StoredTransferJob *putjob = KIO::storedPut(file.readAll(), url, permission, KIO::JobFlag::Overwrite);
+			saveOk = putjob->exec();
+			file.close();
 		}
 	}
 
@@ -678,7 +678,7 @@ void MainDlg::slotPrint()
 	prt.setResolution( 72 );
 	KPrinterDlg* printdlg = new KPrinterDlg( m_parent );
 	printdlg->setObjectName( "KmPlot page" );
-	QPrintDialog *printDialog = new QPrintDialog( &prt, m_parent );
+	QPointer<QPrintDialog> printDialog = new QPrintDialog( &prt, m_parent );
 	printDialog->setOptionTabs( QList<QWidget*>() << printdlg );
 	printDialog->setWindowTitle( i18n("Print Plot") );
 
@@ -718,6 +718,21 @@ void MainDlg::editConstantsModal(QWidget *parent)
 	m_constantEditor->show();
 }
 
+bool MainDlg::fileExists(const QUrl &url)
+{
+	bool fileExists = false;
+	if (url.isValid()) {
+		short int detailLevel = 0; // Lowest level: file/dir/symlink/none
+		KIO::StatJob* statjob = KIO::stat(url, KIO::StatJob::SourceSide, detailLevel);
+		bool noerror = statjob->exec();
+		if (noerror) {
+			// We want a file
+			fileExists = !statjob->statResult().isDir();
+		}
+	}
+	return fileExists;
+}
+
 void MainDlg::slotNames()
 {
 	KHelpClient::invokeHelp( "func-predefined", "kmplot" );
@@ -763,17 +778,7 @@ void MainDlg::graphArea()
 
 void MainDlg::toggleShowSliders()
 {
-	// create the slider if it not exists already
-	if ( !View::self()->m_sliderWindow )
-	{
-		View::self()->m_sliderWindow = new KSliderWindow( View::self() );
-		connect( View::self()->m_sliderWindow, SIGNAL( valueChanged() ), View::self(), SLOT( drawPlot() ) );
-		connect( View::self()->m_sliderWindow, SIGNAL( windowClosed() ), View::self(), SLOT( sliderWindowClosed() ) );
-	}
-	if ( !View::self()->m_sliderWindow->isVisible() )
-		View::self()->m_sliderWindow->show();
-	else
-		View::self()->m_sliderWindow->hide();
+	View::self()->updateSliders();
 }
 
 void MainDlg::setReadOnlyStatusBarText(const QString &text)
@@ -791,7 +796,7 @@ CoordsConfigDialog * MainDlg::coordsDialog( )
 	if ( !m_coordsDialog)
 	{
 		m_coordsDialog = new CoordsConfigDialog(m_parent);
-		connect( m_coordsDialog, SIGNAL( settingsChanged(const QString &) ), View::self(), SLOT(drawPlot() ) );
+		connect( m_coordsDialog, &CoordsConfigDialog::settingsChanged, View::self(), QOverload<>::of(&View::drawPlot) );
 	}
 
 	return m_coordsDialog;
